@@ -4,7 +4,7 @@
 case `uname -m` in
   "x86_64")
     ARCH="linux64"
-    FALLBACK_QT_ROOT=/opt/qt/5.15.1/gcc_64
+    FALLBACK_QT_ROOT=/opt/qt/5.15.2/gcc_64
     FALLBACK_QMAKE_ROOT="$FALLBACK_QT_ROOT/bin"
     ;;
 
@@ -16,17 +16,17 @@ case `uname -m` in
 esac
 
 # Uncomment this line if you want to compile using LLVM (clang) compiler tools
-# QMAKE_ARGS="-r -spec linux-clang"
+# QMAKE_ARGS="pgmodeler.pro -r -spec linux-clang"
 
 # Comment this one if you've decided to use LLVM
-QMAKE_ARGS="-r -spec linux-g++"
+QMAKE_ARGS="pgmodeler.pro -r -spec linux-g++"
 QMAKE_ROOT=/usr/bin
 QMAKE_CMD=qmake
 LOG="$PWD/linuxdeploy.log"
 QT_IFW_ROOT=/opt/qt/Tools/QtInstallerFramework/3.2
 
 # Detecting current pgModeler version
-DEPLOY_VER=`cat libutils/src/globalattributes.cpp | grep PgModelerVersion | sed 's/.\+PgModelerVersion=QString("//g' | sed 's/")\;//g' | sed 's/^ *//g'`
+DEPLOY_VER=`cat libs/libutils/src/globalattributes.cpp | grep PgModelerVersion | sed 's/.\+PgModelerVersion=QString("//g' | sed 's/")//g' | sed 's/^ *//g'`
 
 BUILD_DIR="$PWD/build"
 DIST_DIR="$PWD/dist"
@@ -182,16 +182,16 @@ else
            libQt5Core.so.5 \
            libQt5XcbQpa.so.5 \
            libQt5Svg.so.5 \
-           libicui18n.so.5* \
-           libicuuc.so.5* \
-           libicudata.so.5*"
+           libicui18n.so.* \
+           libicuuc.so.* \
+           libicudata.so.*"
 fi
 
 clear 
 echo 
 echo "pgModeler Linux deployment script"
 echo "PostgreSQL Database Modeler Project - pgmodeler.io"
-echo "Copyright 2006-2020 Raphael A. Silva <raphael@pgmodeler.io>"
+echo "Copyright 2006-2021 Raphael A. Silva <raphael@pgmodeler.io>"
 
 # Identifying System Qt version
 if [ -e "$QMAKE_ROOT/$QMAKE_CMD" ]; then
